/*
 * Copyright (c) 2022 Jonathan Schleifer <js@nil.im>
 *
 * All rights reserved.
 *
 * This file is part of Obj3DEngine. It may be distributed under the terms of
 * the Q Public License 1.0, which can be found in the file LICENSE.QPL
 * included in the packaging of this file.
 *
 * Alternatively, it may be distributed under the terms of the GNU General
 * Public License, either version 2 or 3, which can be found in the file
 * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of
 * this file.
 */

#import <ObjFW/ObjFW.h>

OF_ASSUME_NONNULL_BEGIN

typedef OFPair OF_GENERIC(OFValue *, OFNumber *) *O3DResolution;

typedef struct OF_BOXABLE {
	float x, y;
} O3DVertex;

@protocol O3DRenderer <OFObject>
@property (readonly, nonatomic) OFArray OF_GENERIC(OFPair OF_GENERIC(OFValue *,
    OFNumber *) *) *availableResolutions;
@property (nonatomic) bool syncsToVerticalBlank;

- (instancetype)initWithOptions:
    (nullable OFDictionary OF_GENERIC(OFString *, id) *)options;
- (void)createWithResolution: (O3DResolution)resolution;
- (void)beginFrame;
- (void)setColor: (OFColor *)color;
- (void)drawVertices: (OFData *)vertices;
- (void)endFrame;
@end

#ifdef __cplusplus
extern "C" {
#endif
extern OFString *const O3DRendererDeviceIndex;
extern OFComparisonResult O3DCompareResolution(id _Nullable left,
    id _Nullable right, void *_Nullable context);
#ifdef __cplusplus
}
#endif

OF_ASSUME_NONNULL_END
